configlet create


Cuando agregues un nuevo enfoque, artículo o ejercicio, tendrás que crear archivos con nombres muy específicos. También requieren que se agreguen o actualicen archivos de configuración. Con el comando create, configlet puede hacer todo esto por ti.

Uso

El comando create sirve para crear los archivos que se necesitan para agregar un nuevo enfoque, artículo o ejercicio, además de modificar los archivos de configuración que haga falta.

configlet [global-options] create [command-options]

Options for create:
      --approach <slug>           The slug of the approach
      --article <slug>            The slug of the article
      --practice-exercise <slug>  The slug of the practice exercise
      --concept-exercise <slug>   The slug of the concept exercise
  -e, --exercise <slug>           Only operate on this exercise
  -o, --offline                   Do not update the cached 'problem-specifications' data

Crear un ejercicio de práctica

La documentación sobre cómo agregar un ejercicio de práctica tiene instrucciones detalladas sobre cómo agregar un ejercicio de práctica.

Crear un ejercicio de concepto

Para crear un ejercicio de concepto, hay que especificar su slug:

configlet create --concept-exercise bird-watcher

Esto creará los archivos que requiere el ejercicio de concepto, tal como se especifica en la documentación de ejercicios de concepto.

Por supuesto, esto es solo el primer paso para crear un ejercicio. Después tendrás que:

  • Agregar pruebas al archivo de pruebas
  • Agregar una implementación de ejemplo
  • Definir el contenido del archivo stub
  • Escribir la introducción en .docs/introduction.md
  • Escribir las instrucciones en .docs/instructions.md
  • En el archivo .meta/config.json del ejercicio:
    • Agregar el nombre de usuario de GitHub de los autores del ejercicio a la clave authors
  • En el archivo config.json del track:
    • Verificar o actualizar la dificultad del ejercicio
    • Agregar conceptos a la clave concepts
    • Agregar conceptos a la clave prerequisites

Crear un enfoque

Para crear los archivos de un enfoque, hay que especificar el slug del enfoque y el de su ejercicio:

configlet create --approach recursion --exercise collatz-conjecture

Esto creará los archivos que requiere el enfoque, tal como se especifica en la documentación de enfoques.

Crear un artículo

Para crear los archivos de un artículo, hay que especificar el slug del artículo y el de su ejercicio:

configlet create --article performance --exercise collatz-conjecture

Esto creará los archivos que requiere el artículo, tal como se especifica en la documentación de artículos.